==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-swedish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","E-post");
define("_RE","Sv");
define("_SUBJECT","mne");
define("_PRIVATEMESSAGES","Dina Privata Meddelanden");
define("_CHECKALL","Markera Alla");
define("_FROM","Frn");
define("_DATE","Datum");
define("_DONTHAVEMESSAGES","Du har inga meddelanden");
define("_NOTREAD","Olst");
define("_MSGSTATUS","Meddelandestatus");
define("_PRIVATEMESSAGE","Privat Meddelande");
define("_INDEX","Index");
define("_SENT","Skickat");
define("_PREVIOUSMESSAGE","Fregende Meddelande");
define("_NEXTMESSAGE","Nsta Meddelande");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","Om Postning");
define("_ALLREGCANPOST","Alla medlemmar kan skriva privata meddelanden");
define("_TO","Till");
define("_MESSAGEICON","Meddelandeikon");
define("_MESSAGE","Meddelande");
define("_HTML","HTML");
define("_PMON","P");
define("_PMOFF","Av");
define("_BBCODE","BBCode");
define("_WROTE","skrev");
define("_OPTIONS","Alternativ");
define("_HTMLDISSABLE","Sl av HTML p detta meddelande");
define("_BBCODEDISSABLE","Sl av <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> p detta meddelande");
define("_SMILEDISSABLE","Sl av <a href=\"bb_smilies.php\" target=\"_blank\"><i>smilies</i></a> p detta meddelande");
define("_CANCELREPLY","Avbryt Svar");
define("_CANCELSEND","Avbryt Skicka");
define("_CLEAR","Rensa");
define("_SUBMIT","Skicka");
define("_USERNOTINDB","Den valda medlemmen existerar inte i databasen.");
define("_CHECKNAMEANDTRY","Vnligen kontrollera namnet och frsk igen.");
define("_MSGPOSTED","Ditt meddelande har postats.");
define("_RETURNTOPMSG","Du kan klicka hr fr att ladda om dina privata meddelanden");
define("_MSGDELETED","Dina meddelanden har raderats.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-swedish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","E-post");
define("_RE","Sv");
define("_SUBJECT","mne");
define("_PRIVATEMESSAGES","Dina Privata Meddelanden");
define("_CHECKALL","Markera Alla");
define("_FROM","Frn");
define("_DATE","Datum");
define("_DONTHAVEMESSAGES","Du har inga meddelanden");
define("_NOTREAD","Olst");
define("_MSGSTATUS","Meddelandestatus");
define("_PRIVATEMESSAGE","Privat Meddelande");
define("_INDEX","Index");
define("_SENT","Skickat");
define("_PREVIOUSMESSAGE","Fregende Meddelande");
define("_NEXTMESSAGE","Nsta Meddelande");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","Om Postning");
define("_ALLREGCANPOST","Alla medlemmar kan skriva privata meddelanden");
define("_TO","Till");
define("_MESSAGEICON","Meddelandeikon");
define("_MESSAGE","Meddelande");
define("_HTML","HTML");
define("_PMON","P");
define("_PMOFF","Av");
define("_BBCODE","BBCode");
define("_WROTE","skrev");
define("_OPTIONS","Alternativ");
define("_HTMLDISSABLE","Sl av HTML p detta meddelande");
define("_BBCODEDISSABLE","Sl av <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> p detta meddelande");
define("_SMILEDISSABLE","Sl av <a href=\"bb_smilies.php\" target=\"_blank\"><i>smilies</i></a> p detta meddelande");
define("_CANCELREPLY","Avbryt Svar");
define("_CANCELSEND","Avbryt Skicka");
define("_CLEAR","Rensa");
define("_SUBMIT","Skicka");
define("_USERNOTINDB","Den valda medlemmen existerar inte i databasen.");
define("_CHECKNAMEANDTRY","Vnligen kontrollera namnet och frsk igen.");
define("_MSGPOSTED","Ditt meddelande har postats.");
define("_RETURNTOPMSG","Du kan klicka hr fr att ladda om dina privata meddelanden");
define("_MSGDELETED","Dina meddelanden har raderats.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>
